==> fr-server-7.1.jar: com/fr/web/mobile/core/js/mobile.comboboxeditor.js <==
FR.ComboBoxEditor=FR.MobileComboBoxEditor=FR.extend(FR.BaseComboBoxEditor,{_defaultConfig:function(){return $.extend(FR.MobileComboBoxEditor.superclass._defaultConfig.apply(),{baseCls:"fr-mobile-trigger-widget",leftBtnCls:"fr-mobile-parameter-toolbar-btn-left",rightBtnCls:"fr-mobile-parameter-toolbar-btn-right",sonHeight:44,limitData:30,iconWidth:21,width:120,height:21})},_init:function(){FR.MobileComboBoxEditor.superclass._init.apply(this,arguments);this._initHeader();this._doSearch();this.$popView=$('<div class="popover-content">').appendTo(this.$popover);
this.$contentDiv=$("<div class='scroller'>").appendTo(this.$popView);this.$popover.hide();this.options.need2BuildList=true;window.onorientationchange=this._modifyPopPosition();window.onresize=this._modifyPopPosition()},shouldShowDirectly:function(){return true},addContent2Element:function(){var c=this.options,a=this;this.element.addClass(c.baseCls);this.editComp=$("<div class='fr-mobile-combo-editor'>").appendTo(this.element);this.iconComp=$("<div class='fr-mobile-combo-icon'>").appendTo(this.element);
this.element.css({width:c.width,height:c.height});this.editComp.css({width:c.width-c.iconWidth,height:c.height,lineHeight:c.height+"px"});this.iconComp.css({width:c.iconWidth,height:c.height});var b=this.onTriggerClick.createDelegate(this);this.element.bind("click",function(){b()});if(c.value||c.value===0){this._dealValueWithEvents(c.value)}},_initHeader:function(){var e=this.options,c=this;var d=e.leftBtnCls,a=e.rightBtnCls;this.$mask=$('<div class="popover-mask"></div>').appendTo("body");this.$popover=this._createPopItem();
var f=$("."+d,this.$popover).eq(0);var b=$("."+a,this.$popover).eq(0);this.$popresult=$(".pop-result",this.$popover);this.$searchArea=$("input[type='search']",this.$popover);f.bind("click",function(){c.clearText();c.clearTag()});b.bind("click",function(){c.collapse()});this._bindTitleBtnEvent(f,b);this._bindBodyClick()},_bindBodyClick:function(){var a=this;$("body").bind("click",function(c){if(a.isExpanded()){var b=$(c.target);if(!b.isChildAndSelfOf($(".popover-header",a.$popover))&&!b.isChildAndSelfOf($(".popover-subheader",a.$popover))&&!b.isChildAndSelfOf(a.element)&&b.is(":visible")&&!b.isChildAndSelfOf($("li"),a.$popover)){a.collapse()
}}})},_createPopItem:function(){return $('<div class="popover"><div class="popover-header"><div class="fr-mobile-btn-container"><span class="fr-mobile-parameter-toolbar-btn-left"><span class="pop-btn">'+FR.i18nText("Clear")+'</span></span><span class="fr-mobile-parameter-toolbar-center">'+FR.i18nText("single_choice")+'</span><span class="fr-mobile-parameter-toolbar-btn-right"><span class="pop-btn">'+FR.i18nText("Finish")+'</span></span></div></div><div class="popover-subheader"><div class="fr-mobile-btn-container"><span class="subheader-choose">'+FR.i18nText("Choose")+':</span><span class="pop-result"></span></div></div></div>').appendTo("body")
},_bindTitleBtnEvent:function(c,b){var d=this.options.leftBtnCls,a=this.options.rightBtnCls;c.bind("mousedown",function(){$(this).swapClass(d,d+"-pressed")}).bind("mouseup",function(){$(this).swapClass(d+"-pressed",d)});b.bind("mousedown",function(){$(this).swapClass(a,a+"-pressed")}).bind("mouseup",function(){$(this).swapClass(a+"-pressed",a)})},_doSearch:function(){var a=this,b=this.options;if(this.$searchArea){this.$searchArea.bind("keyup",function(c){setTimeout(function(){var d=a.$searchArea.val();
if(a.searchText==d&&c.keyCode!=FR.keyCode.BACKSPACE){return}a.searchText=d;a._ajaxSearch()},b.searchTime)})}},_ajaxSearch:function(){this.shouldReBuildList();this._buildContent()},shouldReBuildList:function(){this.options.need2BuildList=true;this.options.noMoreData=false},_getViewList:function(){return this.$ul.children("li")},onTriggerClick:function(){if(this.fireEvent(FR.Events.CLICK)===false){return false}if(!this.isEnabled()){return}FR.MobileTools.regClickAction();if(this.isExpanded()){this.collapse()
}else{this._createVieList()}},_createVieList:function(){this.backupScrollPoint={top:$("body")[0].scrollTop,left:$("body")[0].scrollLeft};var b=$("body").children();for(var a=0;a<b.length;a++){var c=$(b[a]);if(c.css("display")!="none"){c.addClass("popoverhidemark").hide()}}this.$mask.show();this.$popover.show();this._modifyPopPosition();FR.MobileWidgetTools.regPopoverResize({scope:this,fn:this._modifyPopPosition});this._buildContent()},_buildContent:function(){if(this.options.need2BuildList){this.$contentDiv.empty();
this.$contentDiv.__loadingMoreData__(true);this.options.data.resetStatus(this.allPara.apply(this,arguments));var b=this.options.data.getData();this._setPopItems(b);this.$contentDiv.__loadingMoreData__(false);this.options.need2BuildList=false}else{this._setPopContentHeight()}if(!this.myScroll){var a=this;this.myScroll=new iScroll(this.$popView[0],{useTransition:true,topOffset:0,onScrollEnd:function(){if(a.options.noMoreData){return}if(this.y<(this.maxScrollY+200)){a._loadMoreData()}}},this.$contentDiv[0])
}else{this.$contentDiv.next().css({top:2*this.options.sonHeight});this.myScroll.refresh()}},_setPopItems:function(a){this._setPopContentHeight();this.$ul=$("<ul>").prependTo(this.$contentDiv);this._addData2View(a)},_setPopContentHeight:function(){var a=Math.floor((window.innerHeight-(2*this.options.sonHeight))/this.options.sonHeight);var b=this.options.sonHeight,d=this.getItemsLength();var c=this.options.maxCount||a;c=Math.min(c,a);this.tH=(d>c?b*c:b*d);this.$popView.height(this.tH)},_addData2View:function(e){var a=this.options.data.getLength();
if(a<this.options.limitData||e.length===0){this.options.noMoreData=true}for(var c=a-e.length;c<a;c++){var b=c+e.length-a;var d=$("<li/>").appendTo(this.$ul);this._initContent(d,e[b].getShowValue(),c);if(this.editComp.text()!==""&&this.editComp.text()==e[b].getShowValue()){this.selectedItem=d;d.addClass("fr-mobile-combo-selected-single");this._createResultTag(e[b].getShowValue())}}if(this.editComp.text()!=""&&this.$popresult.children().length===0){this._createResultTag(this.editComp.text())}},_loadMoreData:function(){this.options.data.resetStatusKeepData(this.allPara(this.options.data.getLength()));
var a=this.options.data.appendData();this._addData2View(a);this.myScroll.refresh()},_checkEmptyContent:function(){if(this.options.allowBlank===false){return}this.emptyContent=$("<li/>");this._initContent(this.emptyContent,this.options.name4Empty,-1);return this.emptyContent},_initContent:function(a,d,c){var b=this;a.append('<span class="pop-item-text">'+d+"</span>").click(function(){if(!FR.MobileTools.isRealClickAction()){return}b._setSelectedIndex(c>-1?c:b.getItemsLength(),$(this));b._onEnterPressed();
b._refreshResultTag()})},_onEnterPressed:function(){this._selectWithoutTriggerEvent();this.fireEvent(FR.Events.AFTEREDIT,this.selectedIndex<this.getItemsLength()?this._getSelectedItem().text():"")},_selectWithoutTriggerEvent:function(){if((this.getItemsLength()>0)&&(this.selectedIndex<this.getItemsLength())){this.setText(this._getSelectedItem().text());this.inList=true}else{this.clearText();this.searchText="";this.options.need2BuildList=true}},_setSelectedIndex:function(a,b){if(this.selectedItem){this.selectedItem.removeClass("fr-mobile-combo-selected-single")
}if(b){b.addClass("fr-mobile-combo-selected-single");this.selectedItem=b}this.selectedIndex=a},_refreshResultTag:function(){if(this.getItemsLength()>0&&(this.selectedIndex!=null&&this.selectedIndex<this.getItemsLength())){this._createResultTag(this._getSelectedItem().text())}},_createResultTag:function(a){this.$popresult.children().remove();this.$popresult.append('<span class="result-tag">'+a+"</span>")},isExpanded:function(){return this.$popover&&this.$popover.is(":visible")},collapse:function(){var b=$("body").children();
for(var a=0;a<b.length;a++){var c=$(b[a]);if(c.hasClass("popoverhidemark")){c.removeClass("popoverhidemark").show()}}if(this.backupScrollPoint){FR.MobileTools.scrollBodyXY(this.backupScrollPoint.left,this.backupScrollPoint.top)}FR.MobileWidgetTools.unregPopoverResize();this.$mask.hide();this.$popover.hide()},_dealValueWithEvents:function(e){var b=this.getValue();if(e==b){return}this.clearResult();this.editComp.text(e);if(this.isExpanded()){this.clearTag();if(e!=""){var a=this.options.data.getRecords();
for(var c=0;c<a.length;c++){var d=a[c];if((d.getValue()==e||d.getShowValue()==e)||(d.getValue()==e||d.getShowValue()==e)){this._setSelectedIndex(c,this.$ul.children().eq(c));break}}}}this._refreshResultTag()},getText:function(){return this.editComp.text()},setText:function(a){this.editComp.text(a)},clearText:function(){this.editComp.text("")},clearResult:function(){this.selectedIndex=null;this.selectedItem=null},clearTag:function(){this.$popresult.children().remove();this.$popover.children().find(".fr-mobile-combo-selected-single").removeClass("fr-mobile-combo-selected-single")
},reset:function(){FR.MobileComboBoxEditor.superclass.reset.apply(this,arguments);this.options.noMoreData=false},_modifyPopPosition:function(){var d=FR.MobileTools.getScreenScale();if(d>1.4){this.$popover.removeClass("popover-oh").addClass("popover-t");this.options.sonHeight=24}else{if(d>1.1){this.$popover.removeClass("popover-t").addClass("popover-oh");this.options.sonHeight=34}else{this.$popover.removeClass("popover-t").removeClass("popover-oh");this.options.sonHeight=44}}if(FR.MobileTools.isLandscape()){var b=document.body.clientWidth;
b=(b>(448/d))?(448/d):b;var c=window.innerWidth;b=Math.min(b,c);var a=0;if(c>b){a+=parseInt((c-b)/2);this.$mask.css({width:c})}this.$popover.css({width:b,height:window.innerHeight,top:0,left:a})}else{this.$popover.css({top:0,left:0,width:window.innerWidth,height:window.innerHeight})}this._doScrollBodyTop()},_doScrollBodyTop:function(){FR.MobileTools.scrollBodyXY(0,0)},doResize:function(b){var a=this.options;this.element.css({width:b.width,height:b.height});this.editComp.css({width:b.width-a.iconWidth,height:b.height,lineHeight:a.height+"px"});
this.iconComp.css({width:a.iconWidth,height:b.height})},scrollToNext:function(){var a=this;if(a.element[0].nextElementSibling){a.element[0].nextElementSibling.scrollIntoView()}},isValueInList:function(a){return true}});$.shortcut("combo",FR.MobileComboBoxEditor);

==> fr-server-7.1.2.jar: com/fr/web/mobile/core/js/mobile.comboboxeditor.js <==
FR.ComboBoxEditor=FR.MobileComboBoxEditor=FR.extend(FR.BaseComboBoxEditor,{_defaultConfig:function(){return $.extend(FR.MobileComboBoxEditor.superclass._defaultConfig.apply(),{baseCls:"fr-mobile-trigger-widget",leftBtnCls:"fr-mobile-parameter-toolbar-btn-left",rightBtnCls:"fr-mobile-parameter-toolbar-btn-right",sonHeight:44,limitData:30,iconWidth:21,width:120,height:21})},_init:function(){FR.MobileComboBoxEditor.superclass._init.apply(this,arguments);this._initHeader();this._doSearch();this.$popView=$('<div class="popover-content">').appendTo(this.$popover);
this.$contentDiv=$("<div class='scroller'>").appendTo(this.$popView);this.$popover.hide();this.options.need2BuildList=true;window.onorientationchange=this._modifyPopPosition();window.onresize=this._modifyPopPosition()},shouldShowDirectly:function(){return true},addContent2Element:function(){var c=this.options,a=this;this.element.addClass(c.baseCls);this.editComp=$("<div class='fr-mobile-combo-editor'>").appendTo(this.element);this.iconComp=$("<div class='fr-mobile-combo-icon'>").appendTo(this.element);
this.element.css({width:c.width,height:c.height});this.editComp.css({width:c.width-c.iconWidth,height:c.height,lineHeight:c.height+"px"});this.iconComp.css({width:c.iconWidth,height:c.height});var b=this.onTriggerClick.createDelegate(this);this.element.bind("click",function(){b()});if(c.value||c.value===0){this._dealValueWithEvents(c.value)}},_initHeader:function(){var e=this.options,c=this;var d=e.leftBtnCls,a=e.rightBtnCls;this.$mask=$('<div class="popover-mask"></div>').appendTo("body");this.$popover=this._createPopItem();
var f=$("."+d,this.$popover).eq(0);var b=$("."+a,this.$popover).eq(0);this.$popresult=$(".pop-result",this.$popover);this.$searchArea=$("input[type='search']",this.$popover);f.bind("click",function(){c.clearText();c.clearTag()});b.bind("click",function(){c.collapse()});this._bindTitleBtnEvent(f,b);this._bindBodyClick()},_bindBodyClick:function(){var a=this;$("body").bind("click",function(c){if(a.isExpanded()){var b=$(c.target);if(!b.isChildAndSelfOf($(".popover-header",a.$popover))&&!b.isChildAndSelfOf($(".popover-subheader",a.$popover))&&!b.isChildAndSelfOf(a.element)&&b.is(":visible")&&!b.isChildAndSelfOf($("li"),a.$popover)){a.collapse()
}}})},_createPopItem:function(){return $('<div class="popover"><div class="popover-header"><div class="fr-mobile-btn-container"><span class="fr-mobile-parameter-toolbar-btn-left"><span class="pop-btn">'+FR.i18nText("Clear")+'</span></span><span class="fr-mobile-parameter-toolbar-center">'+FR.i18nText("single_choice")+'</span><span class="fr-mobile-parameter-toolbar-btn-right"><span class="pop-btn">'+FR.i18nText("Finish")+'</span></span></div></div><div class="popover-subheader"><div class="fr-mobile-btn-container"><span class="subheader-choose">'+FR.i18nText("Choose")+':</span><span class="pop-result"></span></div></div></div>').appendTo("body")
},_bindTitleBtnEvent:function(c,b){var d=this.options.leftBtnCls,a=this.options.rightBtnCls;c.bind("mousedown",function(){$(this).swapClass(d,d+"-pressed")}).bind("mouseup",function(){$(this).swapClass(d+"-pressed",d)});b.bind("mousedown",function(){$(this).swapClass(a,a+"-pressed")}).bind("mouseup",function(){$(this).swapClass(a+"-pressed",a)})},_doSearch:function(){var a=this,b=this.options;if(this.$searchArea){this.$searchArea.bind("keyup",function(c){setTimeout(function(){var d=a.$searchArea.val();
if(a.searchText==d&&c.keyCode!=FR.keyCode.BACKSPACE){return}a.searchText=d;a._ajaxSearch()},b.searchTime)})}},_ajaxSearch:function(){this.shouldReBuildList();this._buildContent()},shouldReBuildList:function(){this.options.need2BuildList=true;this.options.noMoreData=false},_getViewList:function(){return this.$ul.children("li")},onTriggerClick:function(){if(this.fireEvent(FR.Events.CLICK)===false){return false}if(!this.isEnabled()){return}FR.MobileTools.regClickAction();if(this.isExpanded()){this.collapse()
}else{this._createVieList()}},_createVieList:function(){this.backupScrollPoint={top:$("body")[0].scrollTop,left:$("body")[0].scrollLeft};var b=$("body").children();for(var a=0;a<b.length;a++){var c=$(b[a]);if(c.css("display")!="none"){c.addClass("popoverhidemark").hide()}}this.$mask.show();this.$popover.show();this._modifyPopPosition();FR.MobileWidgetTools.regPopoverResize({scope:this,fn:this._modifyPopPosition});this._buildContent()},_buildContent:function(){if(this.options.need2BuildList){this.$contentDiv.empty();
this.$contentDiv.__loadingMoreData__(true);this.options.data.resetStatus(this.allPara.apply(this,arguments));var b=this.options.data.getData();this._setPopItems(b);this.$contentDiv.__loadingMoreData__(false);this.options.need2BuildList=false}else{this._setPopContentHeight()}if(!this.myScroll){var a=this;this.myScroll=new iScroll(this.$popView[0],{useTransition:true,topOffset:0,onScrollEnd:function(){if(a.options.noMoreData){return}if(this.y<(this.maxScrollY+200)){a._loadMoreData()}}},this.$contentDiv[0])
}else{this.$contentDiv.next().css({top:2*this.options.sonHeight});this.myScroll.refresh()}},_setPopItems:function(a){this._setPopContentHeight();this.$ul=$("<ul>").prependTo(this.$contentDiv);this._addData2View(a)},_setPopContentHeight:function(){var a=Math.floor((window.innerHeight-(2*this.options.sonHeight))/this.options.sonHeight);var b=this.options.sonHeight,d=this.getItemsLength();var c=this.options.maxCount||a;c=Math.min(c,a);this.tH=(d>c?b*c:b*d);this.$popView.height(this.tH)},_addData2View:function(e){var a=this.options.data.getLength();
if(a<this.options.limitData||e.length===0){this.options.noMoreData=true}for(var c=a-e.length;c<a;c++){var b=c+e.length-a;var d=$("<li/>").appendTo(this.$ul);this._initContent(d,e[b].getShowValue(),c);if(this.editComp.text()!==""&&this.editComp.text()==e[b].getShowValue()){this.selectedItem=d;d.addClass("fr-mobile-combo-selected-single");this._createResultTag(e[b].getShowValue())}}if(this.editComp.text()!=""&&this.$popresult.children().length===0){this._createResultTag(this.editComp.text())}},_loadMoreData:function(){this.options.data.resetStatusKeepData(this.allPara(this.options.data.getLength()));
var a=this.options.data.appendData();this._addData2View(a);this.myScroll.refresh()},_checkEmptyContent:function(){if(this.options.allowBlank===false){return}this.emptyContent=$("<li/>");this._initContent(this.emptyContent,this.options.name4Empty,-1);return this.emptyContent},_initContent:function(a,d,c){var b=this;a.append('<span class="pop-item-text">'+d+"</span>").click(function(){if(!FR.MobileTools.isRealClickAction()){return}b._setSelectedIndex(c>-1?c:b.getItemsLength(),$(this));b._onEnterPressed();
b._refreshResultTag()})},_onEnterPressed:function(){this._selectWithoutTriggerEvent();this.fireEvent(FR.Events.AFTEREDIT,this.selectedIndex<this.getItemsLength()?this._getSelectedItem().text():"")},_selectWithoutTriggerEvent:function(){if((this.getItemsLength()>0)&&(this.selectedIndex<this.getItemsLength())){this.setText(this._getSelectedItem().text());this.inList=true}else{this.clearText();this.searchText="";this.options.need2BuildList=true}},_setSelectedIndex:function(a,b){if(this.selectedItem){this.selectedItem.removeClass("fr-mobile-combo-selected-single")
}if(b){b.addClass("fr-mobile-combo-selected-single");this.selectedItem=b}this.selectedIndex=a},_refreshResultTag:function(){if(this.getItemsLength()>0&&(this.selectedIndex!=null&&this.selectedIndex<this.getItemsLength())){this._createResultTag(this._getSelectedItem().text())}},_createResultTag:function(a){this.$popresult.children().remove();this.$popresult.append('<span class="result-tag">'+a+"</span>")},isExpanded:function(){return this.$popover&&this.$popover.is(":visible")},collapse:function(){var b=$("body").children();
for(var a=0;a<b.length;a++){var c=$(b[a]);if(c.hasClass("popoverhidemark")){c.removeClass("popoverhidemark").show()}}if(this.backupScrollPoint){FR.MobileTools.scrollBodyXY(this.backupScrollPoint.left,this.backupScrollPoint.top)}FR.MobileWidgetTools.unregPopoverResize();this.$mask.hide();this.$popover.hide()},_dealValueWithEvents:function(e){var b=this.getValue();if(e==b){return}this.clearResult();var g=e;var f=this._findInList(e);if(f!==false){this.cacheInitValue(f,e);g=f}this.editComp.text(g);if(this.isExpanded()){this.clearTag();
if(e!=""){var a=this.options.data.getRecords();for(var c=0;c<a.length;c++){var d=a[c];if((d.getValue()==e||d.getShowValue()==e)||(d.getValue()==e||d.getShowValue()==e)){this._setSelectedIndex(c,this.$ul.children().eq(c));break}}}}this._refreshResultTag()},getText:function(){return this.editComp.text()},setText:function(a){this.editComp.text(a)},clearText:function(){this.editComp.text("")},clearResult:function(){this.selectedIndex=null;this.selectedItem=null},clearTag:function(){this.$popresult.children().remove();
this.$popover.children().find(".fr-mobile-combo-selected-single").removeClass("fr-mobile-combo-selected-single")},reset:function(){FR.MobileComboBoxEditor.superclass.reset.apply(this,arguments);this.options.noMoreData=false},_modifyPopPosition:function(){var d=FR.MobileTools.getScreenScale();if(d>1.4){this.$popover.removeClass("popover-oh").addClass("popover-t");this.options.sonHeight=24}else{if(d>1.1){this.$popover.removeClass("popover-t").addClass("popover-oh");this.options.sonHeight=34}else{this.$popover.removeClass("popover-t").removeClass("popover-oh");
this.options.sonHeight=44}}if(FR.MobileTools.isLandscape()){var b=document.body.clientWidth;b=(b>(448/d))?(448/d):b;var c=window.innerWidth;b=Math.min(b,c);var a=0;if(c>b){a+=parseInt((c-b)/2);this.$mask.css({width:c})}this.$popover.css({width:b,height:window.innerHeight,top:0,left:a})}else{this.$popover.css({top:0,left:0,width:window.innerWidth,height:window.innerHeight})}this._doScrollBodyTop()},_doScrollBodyTop:function(){FR.MobileTools.scrollBodyXY(0,0)},doResize:function(b){var a=this.options;
this.element.css({width:b.width,height:b.height});this.editComp.css({width:b.width-a.iconWidth,height:b.height,lineHeight:a.height+"px"});this.iconComp.css({width:a.iconWidth,height:b.height})},scrollToNext:function(){var a=this;if(a.element[0].nextElementSibling){a.element[0].nextElementSibling.scrollIntoView()}},isValueInList:function(a){return true}});$.shortcut("combo",FR.MobileComboBoxEditor);
